pub struct OverlayConfig {
pub public_overlay_peer_store_period: Duration,
pub public_overlay_peer_store_max_jitter: Duration,
pub public_overlay_peer_store_max_entries: usize,
pub public_overlay_peer_exchange_period: Duration,
pub public_overlay_peer_exchange_max_jitter: Duration,
pub public_overlay_peer_collect_period: Duration,
pub public_overlay_peer_collect_max_jitter: Duration,
pub public_overlay_peer_discovery_period: Duration,
pub public_overlay_peer_discovery_max_jitter: Duration,
pub exchange_public_entries_batch: usize,
pub query_timeout: Duration,
}Fields
public_overlay_peer_store_period: DurationA period of storing public overlay entries in local DHT.
Default: 3 minutes.
public_overlay_peer_store_max_jitter: DurationA maximum value of a random jitter for the entries store period.
Default: 30 seconds.
public_overlay_peer_store_max_entries: usizeA maximum number of public overlay entries to store.
Default: 20.
public_overlay_peer_exchange_period: DurationA period of exchanging public overlay peers.
Default: 3 minutes.
public_overlay_peer_exchange_max_jitter: DurationA maximum value of a random jitter for the peer exchange period.
Default: 30 seconds.
public_overlay_peer_collect_period: DurationA period of collecting public overlay entries.
Default: 3 minutes.
public_overlay_peer_collect_max_jitter: DurationA maximum value of a random jitter for the peer collect period.
Default: 30 seconds.
public_overlay_peer_discovery_period: DurationA period of discovering public overlay peers.
Default: 3 minutes.
public_overlay_peer_discovery_max_jitter: DurationA maximum value of a random jitter for the peer discovery period.
Default: 30 seconds.
exchange_public_entries_batch: usizeNumber of peers to send during entries exchange request.
Default: 20.
query_timeout: DurationTimeout for a single query in collect_public_entries.
Default: 100 ms.